@@ -1,2 +1,4 @@
+#if defined(__OpenBSD__)
 #include <sys/types.h>
 #include "/usr/include/bsd_auth.h"
+#endif
